@@ -5,15 +5,15 @@
  * Copyright (C) 2004 Novell, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
@@ -28,7 +28,7 @@
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtktreednd.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n-lib.h>
 #include "e-contact-store.h"
 
 #define ITER_IS_VALID(contact_store, iter) ((iter)->stamp == (contact_store)->stamp)
@@ -174,6 +174,13 @@ e_contact_store_finalize (GObject *object)
 		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
+/**
+ * e_contact_store_new:
+ *
+ * Creates a new #EContactStore.
+ *
+ * Return value: A new #EContactStore.
+ **/
 EContactStore *
 e_contact_store_new (void)
 {
@@ -245,6 +252,21 @@ find_contact_source_by_book (EContactStore *contact_store, EBook *book)
 	return -1;
 }
 
+EBookView *
+find_contact_source_by_book_return_view(EContactStore *contact_store, EBook *book)
+{
+	gint i;
+
+	ContactSource *source = NULL;
+
+	for(i = 0; i < contact_store->contact_sources->len; i++) {
+		source = &g_array_index (contact_store->contact_sources, ContactSource, i);
+		if (source->book == book)
+			break;
+	}
+	return source->book_view;;
+}
+
 static gint
 find_contact_source_by_view (EContactStore *contact_store, EBookView *book_view)
 {
@@ -360,7 +382,7 @@ find_contact_by_view_and_uid (EContactStore *contact_store, EBookView *find_view
 static gint
 find_contact_by_uid (EContactStore *contact_store, const gchar *find_uid)
 {
-	gint i, j;
+	gint i;
 
 	for (i = 0; i < contact_store->contact_sources->len; i++) {
 		ContactSource *source = &g_array_index (contact_store->contact_sources, ContactSource, i);
@@ -383,7 +405,6 @@ get_book_at_row (EContactStore *contact_store, gint row)
 {
 	ContactSource *source;
 	gint           source_index;
-	gint           offset;
 
 	source_index = find_contact_source_by_offset (contact_store, row);
 	if (source_index < 0)
@@ -417,7 +438,6 @@ static gboolean
 find_contact_source_details_by_view (EContactStore *contact_store, EBookView *book_view,
 				     ContactSource **contact_source, gint *offset)
 {
-	ContactSource *source;
 	gint           source_index;
 
 	source_index = find_contact_source_by_view (contact_store, book_view);
@@ -555,8 +575,10 @@ view_sequence_complete (EContactStore *contact_store, EBookViewStatus status, EB
 	}
 
 	/* If current view finished, do nothing */
-	if (book_view == source->book_view)
+	if (book_view == source->book_view) {
+		stop_view (contact_store, source->book_view);
 		return;
+	}
 
 	g_assert (book_view == source->book_view_pending);
 
@@ -753,6 +775,15 @@ query_contact_source (EContactStore *contact_store, ContactSource *source)
  * EContactStore API *
  * ----------------- */
 
+/**
+ * e_contact_store_get_book:
+ * @contact_store: an #EContactStore
+ * @iter: a #GtkTreeIter from @contact_store
+ *
+ * Gets the #EBook that provided the contact at @iter.
+ *
+ * Return value: An #EBook.
+ **/
 EBook *
 e_contact_store_get_book (EContactStore *contact_store, GtkTreeIter *iter)
 {
@@ -766,6 +797,15 @@ e_contact_store_get_book (EContactStore *contact_store, GtkTreeIter *iter)
 	return get_book_at_row (contact_store, index);
 }
 
+/**
+ * e_contact_store_get_contact:
+ * @contact_store: an #EContactStore
+ * @iter: a #GtkTreeIter from @contact_store
+ *
+ * Gets the #EContact at @iter.
+ *
+ * Return value: An #EContact.
+ **/
 EContact *
 e_contact_store_get_contact (EContactStore *contact_store, GtkTreeIter *iter)
 {
@@ -779,6 +819,16 @@ e_contact_store_get_contact (EContactStore *contact_store, GtkTreeIter *iter)
 	return get_contact_at_row (contact_store, index);
 }
 
+/**
+ * e_contact_store_find_contact:
+ * @contact_store: an #EContactStore
+ * @uid: a unique contact identifier
+ * @iter: a destination #GtkTreeIter to set
+ *
+ * Sets @iter to point to the contact row matching @uid.
+ * 
+ * Return value: %TRUE if the contact was found, and @iter was set. %FALSE otherwise.
+ **/
 gboolean
 e_contact_store_find_contact (EContactStore *contact_store, const gchar *uid,
 			      GtkTreeIter *iter)
@@ -796,6 +846,15 @@ e_contact_store_find_contact (EContactStore *contact_store, const gchar *uid,
 	return TRUE;
 }
 
+/**
+ * e_contact_store_get_books:
+ * @contact_store: an #EContactStore
+ *
+ * Gets the list of books that provide contacts for @contact_store.
+ *
+ * Return value: A #GList of pointers to #EBook. The caller owns the list,
+ * but not the books.
+ **/
 GList *
 e_contact_store_get_books (EContactStore *contact_store)
 {
@@ -814,12 +873,18 @@ e_contact_store_get_books (EContactStore *contact_store)
 	return book_list;
 }
 
+/**
+ * e_contact_store_add_book:
+ * @contact_store: an #EContactStore
+ * @book: an #EBook
+ *
+ * Adds @book to the list of books that provide contacts for @contact_store.
+ **/
 void
 e_contact_store_add_book (EContactStore *contact_store, EBook *book)
 {
 	ContactSource  source;
 	ContactSource *indexed_source;
-	EBookView     *view;
 
 	g_return_if_fail (E_IS_CONTACT_STORE (contact_store));
 	g_return_if_fail (E_IS_BOOK (book));
@@ -840,13 +905,18 @@ e_contact_store_add_book (EContactStore *contact_store, EBook *book)
 	query_contact_source (contact_store, indexed_source);
 }
 
+/**
+ * e_contact_store_remove_book:
+ * @contact_store: an #EContactStore
+ * @book: an #EBook
+ *
+ * Removes @book from the list of books that provide contacts for @contact_store.
+ **/
 void
 e_contact_store_remove_book (EContactStore *contact_store, EBook *book)
 {
 	ContactSource *source;
 	gint           source_index;
-	gint           offset;
-	gint           i;
 
 	g_return_if_fail (E_IS_CONTACT_STORE (contact_store));
 	g_return_if_fail (E_IS_BOOK (book));
@@ -865,6 +935,14 @@ e_contact_store_remove_book (EContactStore *contact_store, EBook *book)
 	g_array_remove_index (contact_store->contact_sources, source_index);  /* Preserve order */
 }
 
+/**
+ * e_contact_store_set_query:
+ * @contact_store: an #EContactStore
+ * @book_query: an #EBookQuery
+ *
+ * Sets @book_query to be the query used to fetch contacts from the books
+ * assigned to @contact_store.
+ **/
 void
 e_contact_store_set_query (EContactStore *contact_store, EBookQuery *book_query)
 {
@@ -891,6 +969,15 @@ e_contact_store_set_query (EContactStore *contact_store, EBookQuery *book_query)
 	}
 }
 
+/**
+ * e_contact_store_peek_query:
+ * @contact_store: an #EContactStore
+ *
+ * Gets the query that's being used to fetch contacts from the books
+ * assigned to @contact_store.
+ *
+ * Return value: The #EBookQuery being used.
+ **/
 EBookQuery *
 e_contact_store_peek_query (EContactStore *contact_store)
 {
@@ -914,8 +1001,6 @@ e_contact_store_get_flags (GtkTreeModel *tree_model)
 static gint
 e_contact_store_get_n_columns (GtkTreeModel *tree_model)
 {
-	EContactStore *contact_store = E_CONTACT_STORE (tree_model);
-
 	g_return_val_if_fail (E_IS_CONTACT_STORE (tree_model), 0);
 
 	return E_CONTACT_FIELD_LAST;
@@ -1038,8 +1123,6 @@ static gboolean
 e_contact_store_iter_has_child (GtkTreeModel *tree_model,
 				GtkTreeIter  *iter)
 {
-	EContactStore *contact_store = E_CONTACT_STORE (tree_model);
-
 	g_return_val_if_fail (E_IS_CONTACT_STORE (tree_model), FALSE);
 
 	if (iter == NULL)
