@@ -46,6 +46,14 @@
 
 G_DEFINE_TYPE (ENameSelectorEntry, e_name_selector_entry, GTK_TYPE_ENTRY);
 
+typedef struct _ENameSelectorEntryPrivate	ENameSelectorEntryPrivate;
+struct _ENameSelectorEntryPrivate
+{
+	gboolean is_completing;
+};
+
+#define E_NAME_SELECTOR_ENTRY_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), E_TYPE_NAME_SELECTOR_ENTRY, ENameSelectorEntryPrivate))
+
 static void e_name_selector_entry_class_init (ENameSelectorEntryClass *name_selector_entry_class);
 static void e_name_selector_entry_init       (ENameSelectorEntry *name_selector_entry);
 static void e_name_selector_entry_dispose    (GObject *object);
@@ -129,6 +137,7 @@ e_name_selector_entry_class_init (ENameSelectorEntryClass *name_selector_entry_c
 
 	/* Install signals */
 
+	g_type_class_add_private (object_class, sizeof(ENameSelectorEntryPrivate));
 }
 
 /* Remove unquoted commas from string */
@@ -741,6 +750,9 @@ type_ahead_complete (ENameSelectorEntry *name_selector_entry)
 	const gchar   *text;
 	gchar         *cue_str;
 	gchar         *temp_str;
+	ENameSelectorEntryPrivate *priv;
+
+	priv = E_NAME_SELECTOR_ENTRY_GET_PRIVATE (name_selector_entry);
 
 	cursor_pos = gtk_editable_get_position (GTK_EDITABLE (name_selector_entry));
 	if (cursor_pos < 0)
@@ -779,6 +791,7 @@ type_ahead_complete (ENameSelectorEntry *name_selector_entry)
 		gtk_editable_insert_text (GTK_EDITABLE (name_selector_entry), textrep, -1, &pos);
 		gtk_editable_select_region (GTK_EDITABLE (name_selector_entry), range_end,
 					    range_start + textrep_len);
+		priv->is_completing = TRUE;
 	}
 
 	if (contact && destination) {
@@ -802,10 +815,15 @@ type_ahead_complete (ENameSelectorEntry *name_selector_entry)
 static void
 clear_completion_model (ENameSelectorEntry *name_selector_entry)
 {
+	ENameSelectorEntryPrivate *priv;
+
+	priv = E_NAME_SELECTOR_ENTRY_GET_PRIVATE (name_selector_entry);
+
 	if (!name_selector_entry->contact_store)
 		return;
 
 	e_contact_store_set_query (name_selector_entry->contact_store, NULL);
+	priv->is_completing = FALSE;
 }
 
 static void
@@ -1285,6 +1303,9 @@ entry_activate (ENameSelectorEntry *name_selector_entry)
 	gint         cursor_pos;
 	gint         range_start, range_end;
 	const gchar *text;
+	ENameSelectorEntryPrivate *priv;
+
+	priv = E_NAME_SELECTOR_ENTRY_GET_PRIVATE (name_selector_entry);
 
 	/* Show us what's really there */
 
@@ -1296,13 +1317,30 @@ entry_activate (ENameSelectorEntry *name_selector_entry)
 	text = gtk_entry_get_text (GTK_ENTRY (name_selector_entry));
 	get_range_at_position (text, cursor_pos, &range_start, &range_end);
 	gtk_editable_set_position (GTK_EDITABLE (name_selector_entry), range_end);
+	
+	priv->is_completing = FALSE;
+}
+
+static gboolean
+user_focus_in (ENameSelectorEntry *name_selector_entry, GdkEventFocus *event_focus)
+{
+	/*
+	 * To preserve selected text, do not propagate the event any more. 
+	 */
+
+	return TRUE;
 }
 
 static gboolean
 user_focus_out (ENameSelectorEntry *name_selector_entry, GdkEventFocus *event_focus)
 {
-	if (!event_focus->in)
+	ENameSelectorEntryPrivate *priv;
+
+	priv = E_NAME_SELECTOR_ENTRY_GET_PRIVATE (name_selector_entry);
+
+	if (!event_focus->in && priv->is_completing) {
 		entry_activate (name_selector_entry);
+	}
 
 	clear_completion_model (name_selector_entry);
 
@@ -1481,10 +1519,8 @@ destination_row_changed (ENameSelectorEntry *name_selector_entry, GtkTreePath *p
 	n = gtk_tree_path_get_indices (path) [0];
 	destination = e_destination_store_get_destination (name_selector_entry->destination_store, iter);
 
-	if (!destination)
-		return;
-
 	g_assert (n >= 0);
+	g_assert (destination != NULL);
 
 	entry_text = gtk_entry_get_text (GTK_ENTRY (name_selector_entry));
 	if (!get_range_by_index (entry_text, n, &range_start, &range_end)) {
@@ -1759,7 +1795,6 @@ editor_closed_cb (GtkObject *editor, gpointer data)
 	g_free (contact_uid);
 	g_object_unref (contact);
 	g_object_unref (editor);
-	g_object_unref (name_selector_entry);
 }
 
 static void
@@ -1831,7 +1866,6 @@ popup_activate_contact (ENameSelectorEntry *name_selector_entry, GtkWidget *menu
 			return;
 
 		contact_list_editor = (*name_selector_entry->contact_list_editor_func) (book, contact, FALSE, TRUE);
-		g_object_ref (name_selector_entry);
 		g_signal_connect (contact_list_editor, "editor_closed",
 				  G_CALLBACK (editor_closed_cb), name_selector_entry);
 	} else {
@@ -1841,7 +1875,6 @@ popup_activate_contact (ENameSelectorEntry *name_selector_entry, GtkWidget *menu
 			return;
 
 		contact_editor = (*name_selector_entry->contact_editor_func) (book, contact, FALSE, TRUE);
-		g_object_ref (name_selector_entry);
 		g_signal_connect (contact_editor, "editor_closed",
 				  G_CALLBACK (editor_closed_cb), name_selector_entry);
 	}
@@ -2041,6 +2074,9 @@ static void
 e_name_selector_entry_init (ENameSelectorEntry *name_selector_entry)
 {
   GtkCellRenderer *renderer;
+  ENameSelectorEntryPrivate *priv;
+
+  priv = E_NAME_SELECTOR_ENTRY_GET_PRIVATE (name_selector_entry);
 
   /* Source list */
 
@@ -2054,6 +2090,7 @@ e_name_selector_entry_init (ENameSelectorEntry *name_selector_entry)
   g_signal_connect (name_selector_entry, "insert-text", G_CALLBACK (user_insert_text), name_selector_entry);
   g_signal_connect (name_selector_entry, "delete-text", G_CALLBACK (user_delete_text), name_selector_entry);
   g_signal_connect (name_selector_entry, "focus-out-event", G_CALLBACK (user_focus_out), name_selector_entry);
+  g_signal_connect_after (name_selector_entry, "focus-in-event", G_CALLBACK (user_focus_in), name_selector_entry);
 
   /* Exposition */
 
@@ -2094,6 +2131,7 @@ e_name_selector_entry_init (ENameSelectorEntry *name_selector_entry)
 
   name_selector_entry->destination_store = e_destination_store_new ();
   setup_destination_store (name_selector_entry);
+  priv->is_completing = FALSE;
 }
 
 /**
